#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 base16
version:              1.0
visibility:           public
id:                   base16-1.0-5AP9opsV45zLVcpoYGsfNM
key:                  base16-1.0-5AP9opsV45zLVcpoYGsfNM
license:              BSD-3-Clause
copyright:            (c) 2020-2023 Emily Pillmore
maintainer:           emilypi@cohomolo.gy
author:               Emily Pillmore
homepage:             https://github.com/emilypi/base16
synopsis:             Fast RFC 4648-compliant Base16 encoding
description:
    RFC 4648-compliant Base16 encodings and decodings.
    This library provides performant encoding and decoding primitives, as well as support for textual values.

category:             Data
abi:                  c0040e03ac418ddf16c8d9419221bed5
exposed:              True
exposed-modules:
    Data.Base16.Types Data.ByteString.Base16
    Data.ByteString.Lazy.Base16 Data.ByteString.Short.Base16
    Data.Text.Encoding.Base16 Data.Text.Encoding.Base16.Error
    Data.Text.Lazy.Encoding.Base16 Data.Text.Short.Encoding.Base16

hidden-modules:
    Data.Base16.Types.Internal Data.ByteString.Base16.Internal.Head
    Data.ByteString.Base16.Internal.Utils
    Data.ByteString.Base16.Internal.W16.Loop
    Data.ByteString.Base16.Internal.W16.ShortLoop

import-dirs:          /usr/lib/ghc-9.6.6/site-local/base16-1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/base16-1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/base16-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-base16
hs-libraries:         HSbase16-1.0-5AP9opsV45zLVcpoYGsfNM
depends:
    base-4.18.2.1 bytestring-0.11.5.3 deepseq-1.4.8.1
    primitive-0.9.1.0-G6koubL8eviAMsrrurXf06 text-2.0.2
    text-short-0.1.6.1-LDbCEoAojljLvWOKBmiM5s

haddock-interfaces:   /usr/share/doc/haskell-base16/html/base16.haddock
haddock-html:         /usr/share/doc/haskell-base16/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

